@@ -1,4 +1,4 @@
-//! Owned objects for use with serialization.
+//! Owned objects are Commits, Trees, Blobs and Tags that can be mutated and serialized.
 
 pub(crate) const NL: &[u8; 1] = b"\n";
 pub(crate) const SPACE: &[u8; 1] = b" ";
@@ -12,8 +12,8 @@ pub use id::{Error, Id};
 mod tag;
 pub use tag::Tag;
 
+///
 pub mod tree;
-#[doc(inline)]
 pub use tree::Tree;
 
 mod commit;
@@ -22,13 +22,16 @@ pub use commit::Commit;
 mod blob {
     use std::io;
 
+    /// A mutable chunk of any [`data`][Blob::data].
     #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
     #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
     pub struct Blob {
+        /// The data itself
         pub data: Vec<u8>,
     }
 
     impl Blob {
+        /// Write the blobs data to `out` verbatim
         pub fn write_to(&self, mut out: impl io::Write) -> io::Result<()> {
             out.write_all(&self.data)
         }
@@ -36,6 +39,7 @@ mod blob {
 }
 pub use blob::Blob;
 
+///
 pub mod signature;
 #[doc(inline)]
 pub use signature::Signature;
