@@ -3,16 +3,24 @@ use bstr::{BStr, BString, ByteSlice};
 use quick_error::quick_error;
 use std::io;
 
+/// A mutable signature is created by an actor at a certain time.
+///
+/// Note that this is not a cryptographical signature.
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
 #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
 pub struct Signature {
+    /// The actors name
     pub name: BString,
+    /// The actor's email
     pub email: BString,
+    /// The time stamp at which the signature is performed
     pub time: Time,
 }
 
 quick_error! {
+    /// The Error produced in by [`Signature::write_to()`]
     #[derive(Debug)]
+    #[allow(missing_docs)]
     pub enum Error {
         IllegalCharacter {
             display("Signature name or email must not contain '<', '>' or \\n")
@@ -27,6 +35,7 @@ impl From<Error> for io::Error {
 }
 
 impl Signature {
+    /// Serialize this instance to `out` in the git serialization format for actors
     pub fn write_to(&self, mut out: impl io::Write) -> io::Result<()> {
         out.write_all(validated_token(self.name.as_bstr())?)?;
         out.write_all(SPACE)?;
